@@ -37,7 +37,7 @@ sub channel_history_menu {
     MENU : while ( 1 ) {
         my @list_size = ( '  ALL', '  50' );
         my $list_size_regexp = join '|', map { quotemeta } @list_size;
-        my ( $channel, $sticky ) = ( '  Channel', '  Sticky' );
+        my ( $channel, $sticky ) = ( '- Channel', '  Sticky' );
         # Choose
         my $choice = choose(
             [ undef, $channel, $sticky, $list_size[$list_size_idx] ],
