@@ -213,16 +213,14 @@ sub _set_preferred_qualities {
 }
 
 
-
-
 sub _get_filename {
     my ( $opt, $info, $video_id, $fmt ) = @_;
     my $title  = $info->{$video_id}{title};
-    my $suffix = $info->{$video_id}{fmt_to_info}{$fmt}{ext};
-    my $gcs_suff = Unicode::GCString->new( $suffix );
-    my $gcs_fmt  = Unicode::GCString->new( $fmt );
-    my $len = $opt->{max_len_f_name} - ( $gcs_suff->columns() + $gcs_fmt->columns() + 2 );
-    my $file_name = unicode_trim( $title, $len );
+    my $suffix = $info->{$video_id}{fmt_to_info}{$fmt}{ext} // 'unknown';
+    my $len_suffix = Unicode::GCString->new( $suffix )->columns();
+    my $len_fmt    = Unicode::GCString->new( $fmt    )->columns();
+    my $len_title  = $opt->{max_len_f_name} - ( $len_suffix + $len_fmt + 2 );
+    my $file_name = unicode_trim( $title, $len_title );
     $file_name = $file_name . '_' . $fmt . '.' . $suffix;
     $file_name =~ s/^\s+|\s+\z//g;
     $file_name =~ s/\s/_/g;
@@ -234,7 +232,6 @@ sub _get_filename {
 }
 
 
-
 sub _fmt_quality {
     my ( $opt, $info, $fmt, $video_id ) = @_;
     my $auto_quality = $opt->{auto_quality};
